@@ -3,10 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Last-in, First-out array
 
-our $VERSION = '0.01';
-
-use strict;
-use warnings;
+our $VERSION = '0.0101';
 
 use Moose;
 use namespace::autoclean;
@@ -92,7 +89,7 @@ Array::LIFO - Last-in, First-out array
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
